==> pkscreener-0.45.20240602.428.tar.gz: pkscreener-0.45.20240602.428/pkscreener/classes/PKScheduledTaskProgress.py <==
"""
    The MIT License (MIT)

    Copyright (c) 2023 pkjmesra

    Permission is hereby granted, free of charge, to any person obtaining a copy
    of this software and associated documentation files (the "Software"), to deal
    in the Software without restriction, including without limitation the rights
    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
    copies of the Software, and to permit persons to whom the Software is
    furnished to do so, subject to the following conditions:

    The above copyright notice and this permission notice shall be included in all
    copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
    SOFTWARE.

"""
from pkscreener.classes.PKScheduler import progressUpdater
class PKScheduledTaskProgress:
    def __init__(self):
        self.tasksDict = {}
    
    def updateProgress(self,taskId):
        task = self.tasksDict.get(taskId)
        if task is not None:
            task.progressStatusDict[taskId] = {"progress": task.progress, "total": task.total}
            if progressUpdater is not None:
                progressUpdater.refresh()

==> pkscreener-0.46.20250912.776.tar.gz: pkscreener-0.46.20250912.776/pkscreener/classes/PKScheduledTaskProgress.py <==
"""
    The MIT License (MIT)

    Copyright (c) 2023 pkjmesra

    Permission is hereby granted, free of charge, to any person obtaining a copy
    of this software and associated documentation files (the "Software"), to deal
    in the Software without restriction, including without limitation the rights
    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
    copies of the Software, and to permit persons to whom the Software is
    furnished to do so, subject to the following conditions:

    The above copyright notice and this permission notice shall be included in all
    copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
    SOFTWARE.

"""
from pkscreener.classes import PKScheduler
class PKScheduledTaskProgress:
    def __init__(self):
        self.tasksDict = {}
    
    def updateProgress(self,taskId):
        task = self.tasksDict.get(taskId)
        global progressUpdater
        progressUpdater = PKScheduler.progressUpdater
        if task is not None:
            task.progressStatusDict[taskId] = {"progress": task.progress, "total": task.total}
            if progressUpdater is not None:
                progressUpdater.refresh()
